###################################################
T&C Power Conversion AG Series Plasma Generator CXN
###################################################

.. autoclass:: pymeasure.instruments.tcpowerconversion.CXN
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.tcpowerconversion.tccxn.PresetChannel
    :members:
    :show-inheritance:
